package com.example.survey.controller;

import com.example.survey.entity.InvestigationRecord;
import com.example.survey.service.InvestigationRecordService;
import com.example.survey.vo.InvestigationRecordVo;
import com.example.survey.vo.ResultVo;
import com.example.survey.vo.ReviewVo;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletResponse;
import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author Pope
 */
@Log4j2
@RestController
@RequestMapping("/investigationRecord")
public class InvestigationRecordController {

    @Autowired
    private InvestigationRecordService investigationRecordService;

    @GetMapping("/underReviewRecord")
    public ResultVo getUnderReviewRecord(@RequestParam(value = "currentPage") Integer currentPage,
                                         @RequestParam(value = "pageSize", defaultValue = "30") Integer pageSize,
                                         @RequestParam(value = "userPhone", required = false) String userPhone,
                                         @RequestParam(value = "state", required = false) String state,
                                         @RequestParam(value = "idNumber", required = false) String idNumber,
                                         @RequestParam(value = "version", required = false) String version,
                                         @RequestParam(value = "questionnaireNumber", required = false) String questionnaireNumber,
                                         @RequestParam(value = "diseased", required = false) Boolean diseased) {

        ResultVo resultVo = new ResultVo();
        resultVo.setCode(ResultVo.SUCCESS);
        resultVo.setMsg("查询成功");
        Map<String, Object> resultMap = new HashMap<>(16, 0.75F);
        List<InvestigationRecord> records = investigationRecordService.listUnderReviewRecordLimit(userPhone, currentPage, pageSize, state, idNumber, version, questionnaireNumber, diseased);
        resultMap.put("totalCount", records.size());
        resultMap.put("currentPage", currentPage);
        resultMap.put("pageSize", pageSize);
        resultMap.put("data", records);
        resultVo.setData(resultMap);

        return resultVo;
    }

    @GetMapping("/underReviewRecordCount")
    public ResultVo countUnderReviewRecord(@RequestParam(value = "userPhone") String userPhone) {
        ResultVo resultVo = new ResultVo();

        resultVo.setCode(ResultVo.SUCCESS);
        resultVo.setMsg("查询成功");
        resultVo.setData(investigationRecordService.countUnderReviewRecord(userPhone));

        return resultVo;
    }


    @PutMapping("/underReviewRecord")
    public ResultVo reviewRecord(@RequestBody ReviewVo reviewVo) {
        ResultVo resultVo = new ResultVo();

        boolean result = investigationRecordService.reviewRecord(reviewVo);
        if (result) {
            resultVo.setCode(ResultVo.SUCCESS);
            resultVo.setMsg("审核成功");
        } else {
            resultVo.setCode(ResultVo.FAILED);
            resultVo.setMsg("审核失败");
        }

        resultVo.setCode(ResultVo.SUCCESS);
        resultVo.setData(result);

        return resultVo;
    }

    @PutMapping("/investigationRecord")
    public ResultVo updateInvestigationRecord(@RequestBody InvestigationRecordVo investigationRecordVo) {
        ResultVo resultVo = new ResultVo();

        investigationRecordService.changeInvestigationRecord(investigationRecordVo);

        resultVo.setCode(ResultVo.SUCCESS);
        resultVo.setMsg("修改提交成功，等待审核");
        resultVo.setData(true);

        return resultVo;
    }

    @PostMapping("/investigationRecord")
    public ResultVo addInvestigationRecord(@RequestBody InvestigationRecordVo investigationRecordVo) {

        ResultVo resultVo = new ResultVo();
        boolean result = investigationRecordService.addInvestigationRecord(investigationRecordVo);
        if (result) {
            resultVo.setCode(ResultVo.SUCCESS);
            resultVo.setMsg("提交成功");
        } else {
            resultVo.setCode(ResultVo.FAILED);
            resultVo.setMsg("提交失败");
        }
        resultVo.setCode(ResultVo.SUCCESS);
        resultVo.setData(result);
        return resultVo;
    }

    @GetMapping("/record2word")
    public void record2Word(@RequestParam("token") String token,
                            @RequestParam("idNumber") String idNumber,
                            HttpServletResponse response) {
        investigationRecordService.export2Word(idNumber, response);
    }

}
