package com.example.survey.controller;

import com.example.survey.enumeration.AuthEnum;
import com.example.survey.service.RoleService;
import com.example.survey.vo.DeleteRoleVo;
import com.example.survey.vo.CreateRoleVo;
import com.example.survey.vo.ModifyRoleVo;
import com.example.survey.vo.ResultVo;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;

/**
 * @author Pope
 */
@RestController
@RequestMapping("/role")
public class RoleController {

    @Autowired
    private RoleService roleService;

    @GetMapping("/role")
    public ResultVo getRole(@RequestParam(value = "pageSize", defaultValue = "30") int pageSize,
                            @RequestParam(value = "currentPage") int currentPage,
                            @RequestParam(value = "roleName", required = false) String roleName) {
        ResultVo resultVo = new ResultVo();


        List<CreateRoleVo> roleVoList = roleService.getRole(roleName, currentPage, pageSize);
        Map<String, Object> resultMap = new HashMap<>(16, 0.75F);
        resultMap.put("totalCount",roleVoList.size());
        resultMap.put("pageSize", pageSize);
        resultMap.put("currentPage", currentPage);
        resultMap.put("data",roleVoList);

        resultVo.setCode(ResultVo.SUCCESS);
        resultVo.setMsg("查询成功");
        resultVo.setData(resultMap);

        return resultVo;
    }

    @PostMapping("/role")
    public ResultVo addRole(@RequestBody CreateRoleVo createRoleVo) {
        ResultVo resultVo = new ResultVo();

        boolean result = roleService.addRole(createRoleVo);
        if (result) {
            resultVo.setCode(ResultVo.SUCCESS);
            resultVo.setMsg("创建成功");
        } else {
            resultVo.setCode(ResultVo.FAILED);
            resultVo.setMsg("创建失败");
        }
        resultVo.setData(result);
        return resultVo;
    }



    @DeleteMapping("/role")
    public ResultVo deleteRole(@RequestBody DeleteRoleVo deleteRoleVo) {
        ResultVo resultVo = new ResultVo();

        roleService.deleteRole(deleteRoleVo.getRoleName());

        resultVo.setCode(ResultVo.SUCCESS);
        resultVo.setMsg("删除成功");
        return resultVo;
    }

    @PutMapping("/role")
    public ResultVo modifyRole(@RequestBody ModifyRoleVo modifyRoleVo) {
        ResultVo resultVo = new ResultVo();

        roleService.modifyRole(modifyRoleVo);

        resultVo.setCode(ResultVo.SUCCESS);
        resultVo.setMsg("修改成功");

        return resultVo;
    }

    @GetMapping("/authList")
    public ResultVo getAuthList() {
        ResultVo resultVo = new ResultVo();

        Map<String, Object> resultMap = new HashMap<>();
        resultMap.put("authList", AuthEnum.getNameList());
        resultVo.setCode(ResultVo.SUCCESS);
        resultVo.setMsg("查询成功");
        resultVo.setData(resultMap);

        return resultVo;
    }


}
