package com.example.survey.dao;

import com.example.survey.entity.InvestigationRecord;
import com.example.survey.entity.User;
import com.example.survey.entity.inner.OperationInformation;

import java.util.List;

/**
 * @author Pope
 */
public interface InvestigationRecordDao {

    /**
     * 插入调查记录
     *
     * @param record 调查记录
     * @return 是否插入成功
     */
    boolean insertInvestigationRecord(InvestigationRecord record);

    /**
     * 根据筛选条件分页查询记录
     *
     * @param userPhone           用户电话号码
     * @param offset              偏移量
     * @param number              数量
     * @param state               调查记录状态
     * @param idNumber            调查对象身份证号
     * @param version             调查记录版本
     * @param questionnaireNumber 问卷编号
     * @param diseased            调查对象是否患病
     * @return 筛选结果
     */
    List<InvestigationRecord> listInvestigationRecordLimit(String userPhone, int offset, int number, String state, String idNumber, String version, String questionnaireNumber, Boolean diseased);

    /**
     * 根据流调人员电话号码查询对应状态的记录数量
     *
     * @param userPhone 流调人员电话号码
     * @param state     记录状态
     * @return 记录数量
     */
    long countInvestigationRecordByUserPhone(String userPhone, String state);

    /**
     * 更新记录状态
     *
     * @param idNumber 调查对象的身份证号
     * @param oldState 旧状态
     * @param newState 新状态
     */
    void updateRecordState(String idNumber, String oldState, String newState);

    /**
     * 根据调查对象身份证号与记录状态查询记录
     *
     * @param idNumber 调查对象的身份证号
     * @param state    记录状态
     * @return 相应记录
     */
    InvestigationRecord selectInvestigationRecord(String idNumber, String state);

    /**
     * 将待审核调查记录修改为审核后的结果
     *
     * @param record 审核后的记录
     */
    void reviewRecord(InvestigationRecord record);

    /**
     * 是否存在当前状态调查记录
     *
     * @param idNumber 调查对象身份证号
     * @param states   调查记录状态
     * @return 是否存在
     */
    boolean existInvestigationRecord(String idNumber, String... states);


    /**
     * 更新所有匹配的调查记录的userPhone字段
     *
     * @param oldUserPhone 旧的userPhone字段
     * @param newUserPhone 新的userPhone字段
     */
    void updateManyRecordUserPhone(String oldUserPhone, String newUserPhone);
}
