package com.example.survey.dao;

import com.example.survey.entity.Role;
import com.example.survey.entity.User;
import com.example.survey.vo.UserInfoVo;
import org.bson.types.ObjectId;

import java.util.List;

/**
 * @author Pope
 */
public interface UserDao {


    /**
     * 根据用户名密码查询用户
     *
     * @param phoneNumber 用户电话号码
     * @param password    密码
     * @return 对应用户
     */
    User selectUser(String phoneNumber, String password);

    /**
     * 插入用户
     *
     * @param user 用户
     * @return 是否插入成功
     */
    boolean insertUser(User user);

    /**
     * 根据筛选条件分页查询用户
     *
     * @param username    用户名  模糊匹配
     * @param phoneNumber 电话号码  精确匹配
     * @param offset      偏移量
     * @param limit       数据量
     * @return 用户信息dto
     */
    List<User> listUserLimit(String username, String phoneNumber, int offset, int limit);

    /**
     * 根据电话号码判断是否存在用户
     *
     * @param phoneNumber 电话号码
     * @return 是否存在用户
     */
    boolean existUser(String phoneNumber);

    /**
     * 删除用户
     *
     * @param phoneNumber 电话号码
     */
    void deleteUser(String phoneNumber);


    /**
     * 从含有该角色的用户的角色列表中删除该用户
     *
     * @param role 角色
     */
    void clearRole(Role role);

    /**
     * 更改用户角色
     *
     * @param phoneNumber 电话号码
     * @param roleList    角色列表
     */
    void updateUserRole(String phoneNumber, List<Role> roleList);

    /**
     * 根据调查人员电话查询用户名
     *
     * @param investigatorPhone 调查人员电话号码
     * @return 用户名
     */
    String selectUsername(String investigatorPhone);

    /**
     * 根据电话号码查询用户
     *
     * @param phoneNumber 电话
     * @return 用户
     */
    User selectUser(String phoneNumber);


    /**
     * 重置密码
     *
     * @param phoneNumber 电话号码
     */
    void resetPwd(String phoneNumber);

    /**
     * 更新用户信息
     *
     * @param userInfoVo 用户信息
     */
    void modifyUser(UserInfoVo userInfoVo);
}
