package com.example.survey.entity;

import com.example.survey.entity.inner.AdministrativeArea;
import com.example.survey.enumeration.RespondentStateEnum;
import com.example.survey.vo.CreateRespondentVo;
import lombok.*;
import org.bson.types.ObjectId;
import org.springframework.data.annotation.Id;
import org.springframework.data.mongodb.core.index.Indexed;
import org.springframework.data.mongodb.core.mapping.Document;

/**
 * @author Pope
 * 调查对象表
 */
@Getter
@Setter
@ToString
@NoArgsConstructor
@AllArgsConstructor
@Document(collection = "respondent")
public class Respondent {

    /**
     * id
     */
    @Id
    private ObjectId id;

    /**
     * 身份证号
     */
    @Indexed(unique = true)
    private String idNumber;

    /**
     * 电话
     */
    private String phoneNumber;

    /**
     * 姓名
     */
    private String name;

    /**
     * 备注
     */
    private String msg;

    /**
     * 分配的调查人员
     */
    @Indexed
    private String userPhone;

    /**
     * 是否发病
     */
    private boolean diseased;

    /**
     * 性别
     */
    private String gender;

    /**
     * 行政区划
     */
    private AdministrativeArea administrativeArea;

    /**
     * 状态
     */
    private String state;

    public Respondent(CreateRespondentVo createRespondentVo) {
        this.idNumber = createRespondentVo.getIdNumber();
        this.phoneNumber = createRespondentVo.getPhoneNumber();
        this.name = createRespondentVo.getName();
        this.msg = createRespondentVo.getMsg();
        this.userPhone = createRespondentVo.getUserPhone();
        this.diseased = createRespondentVo.isDiseased();
        this.gender = createRespondentVo.getGender();
        this.administrativeArea = createRespondentVo.getAdministrativeArea();
        this.state = RespondentStateEnum.NOT_INVESTIGATED.getValue();
    }
}
