package com.example.survey.enumeration;

import java.util.HashSet;
import java.util.LinkedList;
import java.util.List;
import java.util.Set;

/**
 * @author Pope
 */

public enum AuthEnum {

    /**
     * 管理员权限，可以访问所有接口
     */
    ADMIN("管理员", new HashSet<String>() {{
        add("/investigator/investigator : POST");
        add("/investigationRecord/underReviewRecord : GET");
        add("/investigationRecord/underReviewRecordCount : GET");
        add("/investigationRecord/investigationRecord : POST");
        add("/investigationRecord/investigationRecord : PUT");
        add("/investigationRecord/underReviewRecord : PUT");
        add("/investigationRecord/record2word : GET");
        add("/respondent/respondent : POST");
        add("/respondent/respondent : GET");
        add("/user/userRole : PUT");
        add("/user/user : GET");
        add("/user/user : DELETE");
        add("/user/user : POST");
        add("/role/role : POST");
        add("/role/role : GET");
        add("/role/role : DELETE");
        add("/role/role : PUT");
        add("/role/authList : GET");
        add("/user/userInfo : PUT");
        add("/user/pwd : PUT");
    }}),

    /**
     * 查询调查记录的权限
     */
    RETRIEVE_RECORD("查询调查记录的权限", new HashSet<String>() {{
        add("/investigationRecord/underReviewRecord : GET");
        add("/investigationRecord/underReviewRecordCount : GET");
    }}),

    /**
     * 提交记录的权限
     */
    CREATE_RECORD("提交调查记录权限", new HashSet<String>() {{
        add("/investigationRecord/investigationRecord : POST");
    }}),

    /**
     * 修改调查记录信息的权限
     */
    UPDATE_RECORD("修改调查记录权限", new HashSet<String>() {{
        add("/investigationRecord/investigationRecord : PUT");
    }}),

    /**
     * 审核调查记录权限
     */
    REVIEW_RECORD("审核调查记录权限", new HashSet<String>() {{
        add("/investigationRecord/underReviewRecord : PUT");
    }}),

    /**
     * 删除调查记录权限
     */
    DELETE_RECORD("删除调查记录权限", new HashSet<String>() {{

    }}),

    /**
     * 分析调查记录的权限
     */
    ANALYSE_RECORD("分析调查记录权限", new HashSet<String>() {{

    }}),

    /**
     * 可以增删改流调人员信息
     */
    CUD_INVESTIGATOR("增删改流调人员信息的权限", new HashSet<String>() {{

    }}),

    /**
     * 查询流调人员信息
     */
    RETRIEVE_INVESTIGATOR("查询流调人员信息的权限", new HashSet<String>() {{

    }}),

    /**
     * 增删改调查对象信息的权限
     */
    CUD_RESPONDENT("增删改调查对象信息的权限", new HashSet<String>() {{
        add("/respondent/respondent : POST");
    }}),

    /**
     * 查询调查对象信息的权限
     */
    RETRIEVE_RESPONDENT("查询调查对象信息的权限", new HashSet<String>() {{
        add("/respondent/respondent : GET");
    }}),

    /**
     * 查看用户的权限
     */
    RETRIEVE_USER("查看用户的权限", new HashSet<String>() {{
        add("/user/user : GET");
    }}),

    /**
     * 删除用户的权限
     */
    DELETE_USER("删除用户的权限", new HashSet<String>() {{
        add("/user/user : DELETE");
    }}),

    /**
     * 查看角色的权限
     */
    RETRIEVE_ROLE("查看角色的权限", new HashSet<String>() {{
        add("/role/role : GET");
    }}),

    /**
     * 删除角色的权限
     */
    DELETE_ROLE("删除角色的权限", new HashSet<String>() {{
        add("/role/role : DELETE");
    }}),

    /**
     * 修改角色的权限
     */
    UPDATE_ROLE("修改角色的权限", new HashSet<String>() {{
        add("/role/role : PUT");
    }}),

    /**
     * 查看权限列表
     */
    LIST_AUTHORITY("查看权限列表的权限", new HashSet<String>() {{
        add("/role/authList : GET");
    }});


    private String name;
    private Set<String> routes;

    AuthEnum(String name, Set<String> routes) {
        this.name = name;
        this.routes = routes;
    }

    public static AuthEnum getRoleEnum(String name) {
        for (AuthEnum value : AuthEnum.values()) {
            if (value.name.equals(name)) {
                return value;
            }
        }
        return null;
    }

    public static List<String> getNameList() {
        List<String> res = new LinkedList<>();
        for (AuthEnum value : AuthEnum.values()) {
            res.add(value.name);
        }
        return res;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Set<String> getRoutes() {
        return routes;
    }

    public void setRoutes(Set<String> routes) {
        this.routes = routes;
    }
}
