package com.example.survey.service.impl;

import com.example.survey.dao.RespondentDao;
import com.example.survey.dao.UserDao;
import com.example.survey.entity.Respondent;
import com.example.survey.entity.User;
import com.example.survey.entity.inner.AdministrativeArea;
import com.example.survey.service.RespondentService;
import com.example.survey.dto.RespondentDto;
import com.example.survey.vo.CreateRespondentVo;
import lombok.extern.log4j.Log4j2;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;

/**
 * @author Pope
 */
@Log4j2
@Service
public class RespondentServiceImpl implements RespondentService {

    @Autowired
    private RespondentDao respondentDao;

    @Autowired
    private UserDao userDao;

    @Override
    public boolean addRespondent(CreateRespondentVo createRespondentVo) {
        if (!userDao.existUser(createRespondentVo.getUserPhone())) {
            log.error("不存在对应id的用户");
        }
        Respondent respondent = new Respondent(createRespondentVo);

        return respondentDao.insertRespondent(respondent);
    }

    @Override
    public List<RespondentDto> listRespondentLimit(String userPhone, String state, AdministrativeArea administrativeArea, int currentPage, int pageSize) {
        List<RespondentDto> dtoList = new ArrayList<>();
        List<Respondent> respondentList = respondentDao.listRespondentLimit(userPhone, state, administrativeArea, currentPage * pageSize, pageSize);
        for (Respondent respondent : respondentList) {
            User user = userDao.selectUser(respondent.getUserPhone());
            dtoList.add(new RespondentDto(respondent, user));
        }
        return dtoList;
    }

    @Override
    public long countRespondent(String userPhone, String state, AdministrativeArea administrativeArea) {
        return respondentDao.countRespondent(userPhone, state, administrativeArea);
    }

}
